<?php

namespace Drupal\default_content_tools;

use Drupal\Core\DefaultContent\Finder;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Psr\Log\LoggerAwareInterface;
use Psr\Log\LoggerAwareTrait;

/**
 * The service deleting default content.
 */
final class DefaultContentDelete implements LoggerAwareInterface {
  use LoggerAwareTrait;

  /**
   * The constructor.
   *
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entityRepository
   *   The entity repository.
   */
  public function __construct(
    private EntityRepositoryInterface $entityRepository,
  ) {}

  /**
   * Deletes all the content found in a folder.
   *
   * This method was created to make it easy to undo default content created
   * by the Default Content API. Method takes the same input as the Default
   * Content Importer and deletes all corresponding entities found on your site.
   *
   * @param \Drupal\Core\DefaultContent\Finder $content
   *   The content finder.
   */
  public function deleteContent(Finder $content) {
    if (count($content->data) === 0) {
      return;
    }
    /** @var array{_meta: array<mixed>} $decoded */
    foreach ($content->data as $decoded) {
      try {
        [
          'uuid' => $uuid,
          'entity_type' => $entity_type_id,
        ] = $decoded['_meta'];
        assert(is_string($uuid));
        assert(is_string($entity_type_id));
        if ($entity = $this->entityRepository->loadEntityByUuid($entity_type_id, $uuid)) {
          $entity->delete();
          $this->logger->notice('Deleted entity @uuid of type @type',
              ['@uuid' => $uuid, '@type' => $entity_type_id]);
        }
      }
      catch (\Throwable $e) {
        $this->logger->error('Unable to delete entity @uuid of type @type: %reason',
          [
            '@uuid' => $uuid,
            '@type' => $entity_type_id,
            '%reason' => $e->getMessage(),
          ]);
      }
    }
  }

}
